==> style-o-matic-1.1.5.tgz: package/es/components/ButtonBar/ButtonBar.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp, _initialiseProps;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { cloneElement } from "react";
import { CoreComponent, getValidProps, setPropTypesA11y, setCorePropDefaults, ROLE } from "../../lib";
import Button from "../Button/Button.js";
import "./ButtonBar.css";

var ButtonBar = (_temp = _class = function (_CoreComponent) {
  _inherits(ButtonBar, _CoreComponent);

  function ButtonBar(props) {
    _classCallCheck(this, ButtonBar);

    var _this = _possibleConstructorReturn(this, _CoreComponent.call(this, props));

    _initialiseProps.call(_this);

    _this.state = {
      activeItem: ""
    };
    return _this;
  }

  ButtonBar.prototype.render = function render() {
    var _this2 = this;

    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        children = _getValidProps.children,
        props = _getValidProps.props,
        inherited = _getValidProps.inherited;

    return React.createElement(
      Component,
      props,
      React.Children.map(children, function (child) {
        if (typeof child.props !== "undefined" && typeof child.props.uirole !== "undefined" && child.props.uirole === ROLE.BUTTON) {
          return _this2.renderChild(child, inherited);
        }
        return child;
      })
    );
  };

  return ButtonBar;
}(CoreComponent), _class.propTypes = setPropTypesA11y(), _class.defaultProps = setCorePropDefaults({
  renderAs: "div",
  uirole: ROLE.BUTTONBAR,
  id: "buttonbar_id",
  dropdown: false
}), _class.Button = Button, _initialiseProps = function _initialiseProps() {
  var _this3 = this;

  this.handleOnClick = function (e) {
    e.preventDefault();
    e.stopPropagation();
    var itemdex = e.currentTarget.attributes.itemdex;

    var activeItem = itemdex.value;
    if (activeItem === _this3.state.activeItem) {
      _this3.setState({ activeItem: "" });
    } else {
      _this3.setState({ activeItem: activeItem });
    }
  };

  this.renderChild = function (child, props) {
    var role = child.props.uirole || ROLE.BUTTON;
    var activeItem = "button-bar-item_" + _this3.maxIndex;
    var ref = function ref(c) {
      _this3[activeItem] = c;
    };
    if (typeof child.ref !== "string") {
      ref = _this3.chainFunction(child.ref, ref);
    }
    _this3.maxIndex = _this3.maxIndex + 1;
    return cloneElement(child, _extends({}, props, {
      ref: ref,
      itemdex: activeItem,
      active: activeItem === _this3.state.activeItem,
      uiclass: _this3.childPrefix(role),
      onClick: _this3.chainFunction(child.props.onClick, _this3.handleOnClick)
    }));
  };
}, _temp);


export default ButtonBar;

==> style-o-matic-1.1.37.tgz: package/es/components/ButtonBar/ButtonBar.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp, _initialiseProps;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { cloneElement } from "react";
import { CoreComponent, getValidProps, getPropTypesA11y, getCorePropDefaults, ROLE } from "../../lib";
import Button from "../Button/Button.js";
import "./ButtonBar.css";

var ButtonBar = (_temp = _class = function (_CoreComponent) {
  _inherits(ButtonBar, _CoreComponent);

  function ButtonBar(props) {
    _classCallCheck(this, ButtonBar);

    var _this = _possibleConstructorReturn(this, _CoreComponent.call(this, props));

    _initialiseProps.call(_this);

    _this.state = {
      activeItem: ""
    };
    return _this;
  }

  ButtonBar.prototype.render = function render() {
    var _this2 = this;

    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        children = _getValidProps.children,
        props = _getValidProps.props,
        inherited = _getValidProps.inherited;

    return React.createElement(
      Component,
      props,
      React.Children.map(children, function (child) {
        if (typeof child.props !== "undefined" && typeof child.props.uirole !== "undefined" && child.props.uirole === ROLE.BUTTON) {
          return _this2.renderChild(child, inherited);
        }
        return child;
      })
    );
  };

  return ButtonBar;
}(CoreComponent), _class.propTypes = getPropTypesA11y(), _class.defaultProps = getCorePropDefaults({
  renderAs: "div",
  uirole: ROLE.BUTTONBAR,
  id: "buttonbar_id",
  dropdown: false
}), _class.Button = Button, _initialiseProps = function _initialiseProps() {
  var _this3 = this;

  this.handleOnClick = function (e) {
    e.preventDefault();
    e.stopPropagation();
    var itemdex = e.currentTarget.attributes.itemdex;

    var activeItem = itemdex.value;
    if (activeItem === _this3.state.activeItem) {
      _this3.setState({ activeItem: "" });
    } else {
      _this3.setState({ activeItem: activeItem });
    }
  };

  this.renderChild = function (child, props) {
    var role = child.props.uirole || ROLE.BUTTON;
    var activeItem = "button-bar-item_" + _this3.maxIndex;
    var ref = function ref(c) {
      _this3[activeItem] = c;
    };
    if (typeof child.ref !== "string") {
      ref = _this3.chainFunction(child.ref, ref);
    }
    _this3.maxIndex = _this3.maxIndex + 1;
    return cloneElement(child, _extends({}, props, {
      ref: ref,
      itemdex: activeItem,
      active: activeItem === _this3.state.activeItem,
      uiclass: _this3.childPrefix(role),
      onClick: _this3.chainFunction(child.props.onClick, _this3.handleOnClick)
    }));
  };
}, _temp);


export default ButtonBar;
